@@ -111,6 +111,32 @@ class API(object):
         action = 'http://music.163.com/captcha?id=' + str(captcha_id)
         return action
 
+    def user_profile(self, user_id):
+        """
+        {'nickname': 'cosven',
+         'avatarImg': 'xx.jpg',
+         'userType': 0,
+         'authStatus': 0,
+         'expertTags': None,
+         'backgroundUrl': 'xx.jpg',
+         'playCount': 2892,
+         'createdplCnt': 8,
+         'starPlaylist': {...},
+         'playlist': [...],
+         'code': 200
+        }
+        """
+        action = uri_we + '/share/userprofile/info'
+        data = {'userId': user_id}
+        payload = self.encrypt_request(data)
+        res_data = self.request('POST', action, payload)
+        code = res_data['code']
+        if code == 200:
+            return res_data
+        elif code == 400:
+            logger.warn(f'user:{user_id} may be invalid')
+        raise CodeShouldBe200(res_data)
+
     # 用户歌单
     def user_playlists(self, uid, offset=0, limit=200):
         action = uri + '/user/playlist/?offset=' + str(offset) +\
@@ -304,6 +330,18 @@ class API(object):
         return
 
     def weapi_songs_url(self, music_ids, bitrate=320000):
+        """
+        When the expected bitrate song url does not exist, server will
+        return a fallback song url. For example, we request a song
+        url with bitrate=320000. If there only exists a song url with
+        bitrate=128000, the server will return it.
+
+        NOTE(cosven): After some manual testing, we found that the url is
+        None in following cases:
+        1. the song is for vip-user and the current user is not vip.
+        2. the song is a paid song and the current user(may be a vip)
+           has not bought it.
+        """
         url = uri_we + '/song/enhance/player/url'
         data = {
             'ids': music_ids,
@@ -439,10 +477,11 @@ class API(object):
 
     def get_recommend_playlists(self):
         url = uri + '/discovery/recommend/resource'
-        data = self.request('GET', url)
+        payload = self.encrypt_request({})
+        data = self.request('POST', url, payload)
         if data['code'] == 200:
             return data['recommend']
-        return None
+        raise CodeShouldBe200(data)
 
     def get_comment(self, comment_id):
         data = {
